import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { useDispatch } from 'react-redux';
import { showNotification } from '../../../store/notification.slice';
import { updateKnowledgeBase, deleteKnowledgeBase } from '../../../store/knowledgeBase/knowledgeBase.thunks';

// 导入拆分的组件
import Breadcrumb from './components/Breadcrumb';
import KnowledgeBaseForm from './components/KnowledgeBaseForm';
import DeleteConfirmModal from './components/DeleteConfirmModal';
import UserPermissionsManager from './components/UserPermissionsManager';

export default function SettingsTab({ knowledgeBase }) {
    const dispatch = useDispatch();
    const navigate = useNavigate();

    // State for knowledge base form
    const [knowledgeBaseForm, setKnowledgeBaseForm] = useState({
        name: knowledgeBase.name,
        desc: knowledgeBase.desc || knowledgeBase.description || '',
        type: knowledgeBase.type || 'private', // 默认为私有知识库
    });
    const [formErrors, setFormErrors] = useState({});
    const [isSubmitting, setIsSubmitting] = useState(false);
    const [showDeleteConfirm, setShowDeleteConfirm] = useState(false);

    // Handle knowledge base form input change
    const handleInputChange = (e) => {
        const { name, value } = e.target;
        setKnowledgeBaseForm((prev) => ({
            ...prev,
            [name]: value,
        }));

        // Clear error if exists
        if (formErrors[name]) {
            setFormErrors((prev) => ({
                ...prev,
                [name]: '',
            }));
        }
    };

    // Validate knowledge base form
    const validateForm = () => {
        const errors = {};

        if (!knowledgeBaseForm.name.trim()) {
            errors.name = '请输入知识库名称';
        }

        if (!knowledgeBaseForm.desc.trim()) {
            errors.desc = '请输入知识库描述';
        }

        if (!knowledgeBaseForm.type) {
            errors.type = '请选择知识库类型';
        }

        setFormErrors(errors);
        return Object.keys(errors).length === 0;
    };

    // Handle form submission
    const handleSubmit = (e) => {
        e.preventDefault();

        // Validate form
        if (!validateForm()) {
            return;
        }

        setIsSubmitting(true);

        // Dispatch update knowledge base action
        dispatch(
            updateKnowledgeBase({
                id: knowledgeBase.id,
                data: {
                    name: knowledgeBaseForm.name,
                    desc: knowledgeBaseForm.desc,
                    description: knowledgeBaseForm.desc, // Add description field for compatibility
                    type: knowledgeBaseForm.type,
                },
            })
        )
            .unwrap()
            .then(() => {
                dispatch(
                    showNotification({
                        message: '知识库更新成功',
                        type: 'success',
                    })
                );
                setIsSubmitting(false);
            })
            .catch((error) => {
                dispatch(
                    showNotification({
                        message: `更新失败: ${error.message || '未知错误'}`,
                        type: 'danger',
                    })
                );
                setIsSubmitting(false);
            });
    };

    // Handle knowledge base deletion
    const handleDelete = () => {
        setIsSubmitting(true);

        // Dispatch delete knowledge base action
        dispatch(deleteKnowledgeBase(knowledgeBase.id))
            .unwrap()
            .then(() => {
                dispatch(
                    showNotification({
                        message: '知识库已删除',
                        type: 'success',
                    })
                );
                // Navigate back to knowledge base list
                navigate('/knowledge-base');
            })
            .catch((error) => {
                dispatch(
                    showNotification({
                        message: `删除失败: ${error.message || '未知错误'}`,
                        type: 'danger',
                    })
                );
                setIsSubmitting(false);
                setShowDeleteConfirm(false);
            });
    };

    return (
        <>
            {/* Breadcrumb navigation */}
            <Breadcrumb knowledgeBase={knowledgeBase} activeTab='settings' />

            {/* Knowledge Base Form */}
            <KnowledgeBaseForm
                formData={knowledgeBaseForm}
                formErrors={formErrors}
                isSubmitting={isSubmitting}
                onInputChange={handleInputChange}
                onSubmit={handleSubmit}
                onDelete={() => setShowDeleteConfirm(true)}
            />

            {/* User Permissions Manager */}
            <UserPermissionsManager knowledgeBase={knowledgeBase} />

            {/* Delete confirmation modal */}
            <DeleteConfirmModal
                show={showDeleteConfirm}
                title={knowledgeBase.name}
                isSubmitting={isSubmitting}
                onCancel={() => setShowDeleteConfirm(false)}
                onConfirm={handleDelete}
            />
        </>
    );
}
